
.. image:: ../dlib-logo.png
   :alt: Dlib C++ Library 
   :target: http://dlib.net

Dlib is principally a C++ library, however, you can use a number of its tools
from python applications.  This page documents the python API for working with
these dlib tools.  If you haven't done so already, you should probably look at
the python example programs first before consulting this reference.  These
example programs are little mini-tutorials for using dlib from python.  They
are listed on the left of the main dlib web page.

Classes
==============================================

.. include:: classes.txt

Functions
==============================================

.. include:: functions.txt


Detailed API Listing
==============================================

.. toctree::
   :maxdepth: 2

.. automodule:: dlib 
   :members:
   :undoc-members:

.. automodule:: dlib.cuda 
   :members:
   :undoc-members:

.. automodule:: dlib.image_dataset_metadata
   :members:
   :undoc-members:





